( cd usr/lib ; rm -rf liblzma.so )
( cd usr/lib ; ln -sf ../../lib/liblzma.so.0 liblzma.so )
( cd usr/bin ; rm -rf lzcat )
( cd usr/bin ; ln -sf xz lzcat )
( cd usr/bin ; rm -rf lzcmp )
( cd usr/bin ; ln -sf lzdiff lzcmp )
( cd usr/bin ; rm -rf xzcat )
( cd usr/bin ; ln -sf xz xzcat )
( cd usr/bin ; rm -rf lzfgrep )
( cd usr/bin ; ln -sf lzgrep lzfgrep )
( cd usr/bin ; rm -rf unxz )
( cd usr/bin ; ln -sf xz unxz )
( cd usr/bin ; rm -rf unlzma )
( cd usr/bin ; ln -sf xz unlzma )
( cd usr/bin ; rm -rf lzma )
( cd usr/bin ; ln -sf xz lzma )
( cd usr/bin ; rm -rf lzegrep )
( cd usr/bin ; ln -sf lzgrep lzegrep )
( cd usr/bin ; rm -rf xz )
( cd usr/bin ; ln -sf ../../bin/xz xz )
( cd usr/bin ; rm -rf lzless )
( cd usr/bin ; ln -sf lzmore lzless )
( cd usr/man/man1 ; rm -rf lzless.1.gz )
( cd usr/man/man1 ; ln -sf lzmore.1.gz lzless.1.gz )
( cd usr/man/man1 ; rm -rf lzfgrep.1.gz )
( cd usr/man/man1 ; ln -sf lzgrep.1.gz lzfgrep.1.gz )
( cd usr/man/man1 ; rm -rf lzcmp.1.gz )
( cd usr/man/man1 ; ln -sf lzdiff.1.gz lzcmp.1.gz )
( cd usr/man/man1 ; rm -rf lzegrep.1.gz )
( cd usr/man/man1 ; ln -sf lzgrep.1.gz lzegrep.1.gz )
( cd lib ; rm -rf liblzma.so.0 )
( cd lib ; ln -sf liblzma.so.0.0.0 liblzma.so.0 )
